summary refs log tree commit diff
path: root/pkgs/development
diff options
context:
space:
mode:
authordavidak <git@davidak.de>2017-08-07 00:05:18 +0200
committerdavidak <git@davidak.de>2017-08-07 21:41:30 +0200
commit3270aa896bc78ee261c34137035d2705aba78440 (patch)
tree01c1f1bca1cd4bd6aedaca8114d6e980612beb53 /pkgs/development
parentff9479cd543545899cfd6cc20bb446e5a6bf4603 (diff)
downloadnixpkgs-3270aa896bc78ee261c34137035d2705aba78440.tar
nixpkgs-3270aa896bc78ee261c34137035d2705aba78440.tar.gz
nixpkgs-3270aa896bc78ee261c34137035d2705aba78440.tar.bz2
nixpkgs-3270aa896bc78ee261c34137035d2705aba78440.tar.lz
nixpkgs-3270aa896bc78ee261c34137035d2705aba78440.tar.xz
nixpkgs-3270aa896bc78ee261c34137035d2705aba78440.tar.zst
nixpkgs-3270aa896bc78ee261c34137035d2705aba78440.zip
replace "Mac OS X" and "OS X" with "macOS"
as it is the official name since 2016

https://en.wikipedia.org/wiki/Macintosh_operating_systems#Desktop

exception are parts refering to older versions of macOS like

"GUI support for Mac OS X 10.6 - 10.12. Note that Emacs 23 and later [...]"
Diffstat (limited to 'pkgs/development')
-rw-r--r--pkgs/development/compilers/chicken/default.nix2
-rw-r--r--pkgs/development/compilers/llvm/3.8/llvm.nix2
-rwxr-xr-xpkgs/development/compilers/ocaml/configure-3.08.02
-rw-r--r--pkgs/development/haskell-modules/generic-builder.nix4
-rw-r--r--pkgs/development/haskell-modules/hackage-packages.nix20
-rw-r--r--pkgs/development/haskell-modules/with-packages-wrapper.nix2
-rw-r--r--pkgs/development/libraries/freenect/default.nix2
-rw-r--r--pkgs/development/libraries/hunspell/default.nix4
-rw-r--r--pkgs/development/libraries/libmemcached/default.nix2
-rw-r--r--pkgs/development/libraries/libserialport/default.nix2
-rw-r--r--pkgs/development/libraries/libsndfile/default.nix2
-rw-r--r--pkgs/development/libraries/opencv/3.x.nix4
-rw-r--r--pkgs/development/libraries/wxwidgets/2.8/default.nix2
-rw-r--r--pkgs/development/libraries/wxwidgets/2.9/default.nix2
-rw-r--r--pkgs/development/libraries/wxwidgets/3.0/default.nix2
-rw-r--r--pkgs/development/libraries/wxwidgets/3.0/mac.nix2
-rw-r--r--pkgs/development/mobile/titaniumenv/build-app.nix4
-rw-r--r--pkgs/development/ocaml-modules/ocamlnat/default.nix2
-rw-r--r--pkgs/development/pharo/vm/build-vm.nix2
-rw-r--r--pkgs/development/python-modules/pyqt/4.x.nix2
-rw-r--r--pkgs/development/tools/gtk-mac-bundler/default.nix2
21 files changed, 34 insertions, 34 deletions
diff --git a/pkgs/development/compilers/chicken/default.nix b/pkgs/development/compilers/chicken/default.nix
index 24d583ed886..792ecc739a5 100644
--- a/pkgs/development/compilers/chicken/default.nix
+++ b/pkgs/development/compilers/chicken/default.nix
@@ -69,7 +69,7 @@ stdenv.mkDerivation {
       CHICKEN is a compiler for the Scheme programming language.
       CHICKEN produces portable and efficient C, supports almost all
       of the R5RS Scheme language standard, and includes many
-      enhancements and extensions. CHICKEN runs on Linux, MacOS X,
+      enhancements and extensions. CHICKEN runs on Linux, macOS,
       Windows, and many Unix flavours.
     '';
   };
diff --git a/pkgs/development/compilers/llvm/3.8/llvm.nix b/pkgs/development/compilers/llvm/3.8/llvm.nix
index ee0a50c9397..a3f652d783b 100644
--- a/pkgs/development/compilers/llvm/3.8/llvm.nix
+++ b/pkgs/development/compilers/llvm/3.8/llvm.nix
@@ -40,7 +40,7 @@ in stdenv.mkDerivation rec {
   patches = [ ./D17533-1.patch ] ++
     stdenv.lib.optionals (!stdenv.isDarwin) [./fix-llvm-config.patch];
 
-  # hacky fix: New LLVM releases require a newer OS X SDK than
+  # hacky fix: New LLVM releases require a newer macOS SDK than
   # 10.9. This is a temporary measure until nixpkgs darwin support is
   # updated.
   postPatch = stdenv.lib.optionalString stdenv.isDarwin ''
diff --git a/pkgs/development/compilers/ocaml/configure-3.08.0 b/pkgs/development/compilers/ocaml/configure-3.08.0
index c62da78ab9f..9c870585512 100755
--- a/pkgs/development/compilers/ocaml/configure-3.08.0
+++ b/pkgs/development/compilers/ocaml/configure-3.08.0
@@ -45,7 +45,7 @@ gcc_warnings="-Wall"
 unset LANG
 unset LC_ALL LC_CTYPE LC_COLLATE LC_MESSAGES LC_MONETARY LC_NUMERIC LC_TIME 
 
-# Turn off some MacOS X debugging stuff, same reason
+# Turn off some macOS debugging stuff, same reason
 unset RC_TRACE_ARCHIVES RC_TRACE_DYLIBS RC_TRACE_PREBINDING_DISABLED
 
 # Parse command-line arguments
diff --git a/pkgs/development/haskell-modules/generic-builder.nix b/pkgs/development/haskell-modules/generic-builder.nix
index 7e99300a41e..9c1e75232d7 100644
--- a/pkgs/development/haskell-modules/generic-builder.nix
+++ b/pkgs/development/haskell-modules/generic-builder.nix
@@ -231,10 +231,10 @@ stdenv.mkDerivation ({
       fi
     done
   '' + (optionalString stdenv.isDarwin ''
-    # Work around a limit in the Mac OS X Sierra linker on the number of paths
+    # Work around a limit in the macOS Sierra linker on the number of paths
     # referenced by any one dynamic library:
     #
-    # Create a local directory with symlinks of the *.dylib (Mac OS X shared
+    # Create a local directory with symlinks of the *.dylib (macOS shared
     # libraries) from all the dependencies.
     local dynamicLinksDir="$out/lib/links"
     mkdir -p $dynamicLinksDir
diff --git a/pkgs/development/haskell-modules/hackage-packages.nix b/pkgs/development/haskell-modules/hackage-packages.nix
index 3b2d9594d98..b8ae7c4016e 100644
--- a/pkgs/development/haskell-modules/hackage-packages.nix
+++ b/pkgs/development/haskell-modules/hackage-packages.nix
@@ -83327,7 +83327,7 @@ self: {
        libraryHaskellDepends = [ array base containers glib gtk mtl ];
        libraryPkgconfigDepends = [ gtk-mac-integration-gtk2 ];
        homepage = "http://www.haskell.org/gtk2hs/";
-       description = "Bindings for the Gtk/OS X integration library";
+       description = "Bindings for the Gtk/macOS integration library";
        license = stdenv.lib.licenses.lgpl21;
        hydraPlatforms = stdenv.lib.platforms.none;
      }) {gtk-mac-integration-gtk2 = null;};
@@ -83591,7 +83591,7 @@ self: {
        libraryHaskellDepends = [ array base containers glib gtk3 mtl ];
        libraryPkgconfigDepends = [ gtk-mac-integration-gtk3 ];
        homepage = "http://www.haskell.org/gtk2hs/";
-       description = "Bindings for the Gtk/OS X integration library";
+       description = "Bindings for the Gtk/macOS integration library";
        license = stdenv.lib.licenses.lgpl21;
        hydraPlatforms = stdenv.lib.platforms.none;
      }) {gtk-mac-integration-gtk3 = null;};
@@ -95058,7 +95058,7 @@ self: {
        librarySystemDepends = [ Cocoa ];
        libraryToolDepends = [ CoreServices ];
        homepage = "http://github.com/luite/hfsevents";
-       description = "File/folder watching for OS X";
+       description = "File/folder watching for macOS";
        license = stdenv.lib.licenses.bsd3;
        platforms = [ "x86_64-darwin" ];
        hydraPlatforms = stdenv.lib.platforms.none;
@@ -108820,7 +108820,7 @@ self: {
        libraryPkgconfigDepends = [ ige-mac-integration ];
        libraryToolDepends = [ gtk2hs-buildtools ];
        homepage = "http://www.haskell.org/gtk2hs/";
-       description = "Bindings for the Gtk/OS X integration library";
+       description = "Bindings for the Gtk/macOS integration library";
        license = stdenv.lib.licenses.lgpl21;
        hydraPlatforms = stdenv.lib.platforms.none;
      }) {ige-mac-integration = null;};
@@ -130347,7 +130347,7 @@ self: {
        isLibrary = false;
        isExecutable = true;
        executableHaskellDepends = [ base GLUT haskell98 unix ];
-       description = "Shows how to run grabber on Mac OS X";
+       description = "Shows how to run grabber on macOS";
        license = stdenv.lib.licenses.bsd3;
        hydraPlatforms = stdenv.lib.platforms.none;
      }) {};
@@ -130745,7 +130745,7 @@ self: {
        isExecutable = true;
        enableSeparateDataOutput = true;
        executableHaskellDepends = [ base directory filepath haskell98 ];
-       description = "Makes an OS X .app bundle from a binary.";
+       description = "Makes an macOS .app bundle from a binary.";
        license = "GPL";
        hydraPlatforms = stdenv.lib.platforms.none;
      }) {};
@@ -142686,7 +142686,7 @@ self: {
        sha256 = "1d2lna7gvygiq062p2y1zy182wv3vkr0lda49y502ad6jf483xdn";
        enableSeparateDataOutput = true;
        libraryHaskellDepends = [ base binary bytestring containers ];
-       description = "Parser for OS X static archive format";
+       description = "Parser for macOS static archive format";
        license = stdenv.lib.licenses.bsd3;
      }) {};
 
@@ -149409,7 +149409,7 @@ self: {
        sha256 = "0xsx1pvlnqyidpvswisir9p9054r7fczi81nccflazijn3pr9rgb";
        enableSeparateDataOutput = true;
        libraryHaskellDepends = [ base base64-bytestring bytestring hxt ];
-       description = "Generate and parse Mac OS X property list format";
+       description = "Generate and parse macOS property list format";
        license = stdenv.lib.licenses.bsd3;
      }) {};
 
@@ -178266,7 +178266,7 @@ self: {
          test-framework-hunit test-framework-quickcheck2 time unix
        ];
        homepage = "https://bitbucket.org/ssaasen/spy";
-       description = "A compact file system watcher for Mac OS X, Linux and Windows";
+       description = "A compact file system watcher for macOS, Linux and Windows";
        license = stdenv.lib.licenses.bsd3;
      }) {};
 
@@ -197119,7 +197119,7 @@ self: {
        sha256 = "1gnrq6s7pipjqfyispkxib3xfzii1ss6a9iwv07mvb5a93hc45cw";
        enableSeparateDataOutput = true;
        libraryHaskellDepends = [ base binary bytestring ];
-       description = "Parser for OS X Universal Binary format";
+       description = "Parser for macOS Universal Binary format";
        license = stdenv.lib.licenses.bsd3;
      }) {};
 
diff --git a/pkgs/development/haskell-modules/with-packages-wrapper.nix b/pkgs/development/haskell-modules/with-packages-wrapper.nix
index 147a021ff53..ec7d961581a 100644
--- a/pkgs/development/haskell-modules/with-packages-wrapper.nix
+++ b/pkgs/development/haskell-modules/with-packages-wrapper.nix
@@ -97,7 +97,7 @@ symlinkJoin {
       fi
     done
   '' + (lib.optionalString stdenv.isDarwin ''
-    # Work around a linker limit in Mac OS X Sierra (see generic-builder.nix):
+    # Work around a linker limit in macOS Sierra (see generic-builder.nix):
     local packageConfDir="$out/lib/${ghc.name}/package.conf.d";
     local dynamicLinksDir="$out/lib/links"
     mkdir -p $dynamicLinksDir
diff --git a/pkgs/development/libraries/freenect/default.nix b/pkgs/development/libraries/freenect/default.nix
index 136f18b0614..c77c3b3640b 100644
--- a/pkgs/development/libraries/freenect/default.nix
+++ b/pkgs/development/libraries/freenect/default.nix
@@ -15,7 +15,7 @@ stdenv.mkDerivation rec {
   nativeBuildInputs = [ cmake pkgconfig ];
 
   meta = {
-    description = "Drivers and libraries for the Xbox Kinect device on Windows, Linux, and OS X";
+    description = "Drivers and libraries for the Xbox Kinect device on Windows, Linux, and macOS";
     inherit version;
     homepage = http://openkinect.org;
     license = with stdenv.lib.licenses; [ gpl2 asl20 ];
diff --git a/pkgs/development/libraries/libmemcached/default.nix b/pkgs/development/libraries/libmemcached/default.nix
index a0e3bb52dfe..086ba8f32d2 100644
--- a/pkgs/development/libraries/libmemcached/default.nix
+++ b/pkgs/development/libraries/libmemcached/default.nix
@@ -11,7 +11,7 @@ stdenv.mkDerivation rec {
   # Fix linking against libpthread (patch from Fedora)
   # https://bugzilla.redhat.com/show_bug.cgi?id=1037707
   # https://bugs.launchpad.net/libmemcached/+bug/1281907
-  # Fix building on OS X (patch from Homebrew)
+  # Fix building on macOS (patch from Homebrew)
   # https://bugs.launchpad.net/libmemcached/+bug/1245562
   patches = stdenv.lib.optional stdenv.isLinux ./libmemcached-fix-linking-with-libpthread.patch
     ++ stdenv.lib.optional stdenv.isDarwin (fetchpatch {
diff --git a/pkgs/development/libraries/libserialport/default.nix b/pkgs/development/libraries/libserialport/default.nix
index e7ee188c29f..ab10e34e230 100644
--- a/pkgs/development/libraries/libserialport/default.nix
+++ b/pkgs/development/libraries/libserialport/default.nix
@@ -14,7 +14,7 @@ stdenv.mkDerivation rec {
     description = "Cross-platform shared library for serial port access";
     homepage = http://sigrok.org/;
     license = licenses.gpl3Plus;
-    # Mac OS X, Windows and Android is also supported (according to upstream).
+    # macOS, Windows and Android is also supported (according to upstream).
     platforms = platforms.linux;
     maintainers = [ maintainers.bjornfor ];
   };
diff --git a/pkgs/development/libraries/libsndfile/default.nix b/pkgs/development/libraries/libsndfile/default.nix
index bd5d0fd733c..180d217ddf1 100644
--- a/pkgs/development/libraries/libsndfile/default.nix
+++ b/pkgs/development/libraries/libsndfile/default.nix
@@ -41,7 +41,7 @@ stdenv.mkDerivation rec {
       code format under the GNU Lesser General Public License.
 
       The library was written to compile and run on a Linux system but
-      should compile and run on just about any Unix (including MacOS X).
+      should compile and run on just about any Unix (including macOS).
       There are also pre-compiled binaries available for 32 and 64 bit
       windows.
 
diff --git a/pkgs/development/libraries/opencv/3.x.nix b/pkgs/development/libraries/opencv/3.x.nix
index 0443d00a258..29d0a1a3a4c 100644
--- a/pkgs/development/libraries/opencv/3.x.nix
+++ b/pkgs/development/libraries/opencv/3.x.nix
@@ -37,7 +37,7 @@ let
     sha256 = "1lynpbxz1jay3ya5y45zac5v8c6ifgk4ssn8d1chfdk3spi691jj";
   };
 
-  # This fixes the build on OS X.
+  # This fixes the build on macOS.
   # See: https://github.com/opencv/opencv_contrib/pull/926
   contribOSXFix = fetchpatch {
     url = "https://github.com/opencv/opencv_contrib/commit/abf44fcccfe2f281b7442dac243e37b7f436d961.patch";
@@ -69,7 +69,7 @@ stdenv.mkDerivation rec {
     (lib.optionalString enableContrib ''
       cp --no-preserve=mode -r "${contribSrc}/modules" "$NIX_BUILD_TOP/opencv_contrib"
 
-      # This fixes the build on OS X.
+      # This fixes the build on macOS.
       patch -d "$NIX_BUILD_TOP/opencv_contrib" -p2 < "${contribOSXFix}"
 
       for name in vgg_generated_48.i \
diff --git a/pkgs/development/libraries/wxwidgets/2.8/default.nix b/pkgs/development/libraries/wxwidgets/2.8/default.nix
index d9e84008b31..9ce8e95d9e9 100644
--- a/pkgs/development/libraries/wxwidgets/2.8/default.nix
+++ b/pkgs/development/libraries/wxwidgets/2.8/default.nix
@@ -68,7 +68,7 @@ stdenv.mkDerivation rec {
     platforms = platforms.linux;
     license = licenses.wxWindows;
     homepage = https://www.wxwidgets.org/;
-    description = "a C++ library that lets developers create applications for Windows, Mac OS X, Linux and other platforms with a single code base";
+    description = "a C++ library that lets developers create applications for Windows, macOS, Linux and other platforms with a single code base";
     longDescription = "wxWidgets gives you a single, easy-to-use API for writing GUI applications on multiple platforms that still utilize the native platform's controls and utilities. Link with the appropriate library for your platform and compiler, and your application will adopt the look and feel appropriate to that platform. On top of great GUI functionality, wxWidgets gives you: online help, network programming, streams, clipboard and drag and drop, multithreading, image loading and saving in a variety of popular formats, database support, HTML viewing and printing, and much more.";
   };
 }
diff --git a/pkgs/development/libraries/wxwidgets/2.9/default.nix b/pkgs/development/libraries/wxwidgets/2.9/default.nix
index a42189331d0..56080841ca3 100644
--- a/pkgs/development/libraries/wxwidgets/2.9/default.nix
+++ b/pkgs/development/libraries/wxwidgets/2.9/default.nix
@@ -70,7 +70,7 @@ stdenv.mkDerivation {
     platforms = with platforms; darwin ++ linux;
     license = licenses.wxWindows;
     homepage = https://www.wxwidgets.org/;
-    description = "a C++ library that lets developers create applications for Windows, Mac OS X, Linux and other platforms with a single code base";
+    description = "a C++ library that lets developers create applications for Windows, macOS, Linux and other platforms with a single code base";
     longDescription = "wxWidgets gives you a single, easy-to-use API for writing GUI applications on multiple platforms that still utilize the native platform's controls and utilities. Link with the appropriate library for your platform and compiler, and your application will adopt the look and feel appropriate to that platform. On top of great GUI functionality, wxWidgets gives you: online help, network programming, streams, clipboard and drag and drop, multithreading, image loading and saving in a variety of popular formats, database support, HTML viewing and printing, and much more.";
   };
 }
diff --git a/pkgs/development/libraries/wxwidgets/3.0/default.nix b/pkgs/development/libraries/wxwidgets/3.0/default.nix
index 6e33f5580cd..35300ed9419 100644
--- a/pkgs/development/libraries/wxwidgets/3.0/default.nix
+++ b/pkgs/development/libraries/wxwidgets/3.0/default.nix
@@ -86,7 +86,7 @@ stdenv.mkDerivation {
     platforms = with platforms; darwin ++ linux;
     license = licenses.wxWindows;
     homepage = https://www.wxwidgets.org/;
-    description = "a C++ library that lets developers create applications for Windows, Mac OS X, Linux and other platforms with a single code base";
+    description = "a C++ library that lets developers create applications for Windows, macOS, Linux and other platforms with a single code base";
     longDescription = "wxWidgets gives you a single, easy-to-use API for writing GUI applications on multiple platforms that still utilize the native platform's controls and utilities. Link with the appropriate library for your platform and compiler, and your application will adopt the look and feel appropriate to that platform. On top of great GUI functionality, wxWidgets gives you: online help, network programming, streams, clipboard and drag and drop, multithreading, image loading and saving in a variety of popular formats, database support, HTML viewing and printing, and much more.";
   };
 }
diff --git a/pkgs/development/libraries/wxwidgets/3.0/mac.nix b/pkgs/development/libraries/wxwidgets/3.0/mac.nix
index 0e246829439..9c307b2d15a 100644
--- a/pkgs/development/libraries/wxwidgets/3.0/mac.nix
+++ b/pkgs/development/libraries/wxwidgets/3.0/mac.nix
@@ -103,7 +103,7 @@ stdenv.mkDerivation rec {
     license = licenses.wxWindows;
     maintainers = [ maintainers.lnl7 ];
     homepage = https://www.wxwidgets.org/;
-    description = "a C++ library that lets developers create applications for Windows, Mac OS X, Linux and other platforms with a single code base";
+    description = "a C++ library that lets developers create applications for Windows, macOS, Linux and other platforms with a single code base";
     longDescription = "wxWidgets gives you a single, easy-to-use API for writing GUI applications on multiple platforms that still utilize the native platform's controls and utilities. Link with the appropriate library for your platform and compiler, and your application will adopt the look and feel appropriate to that platform. On top of great GUI functionality, wxWidgets gives you: online help, network programming, streams, clipboard and drag and drop, multithreading, image loading and saving in a variety of popular formats, database support, HTML viewing and printing, and much more.";
   };
 }
diff --git a/pkgs/development/mobile/titaniumenv/build-app.nix b/pkgs/development/mobile/titaniumenv/build-app.nix
index cf699c34e2b..0c9c3e3f42c 100644
--- a/pkgs/development/mobile/titaniumenv/build-app.nix
+++ b/pkgs/development/mobile/titaniumenv/build-app.nix
@@ -21,7 +21,7 @@ let
     security delete-keychain $keychainName
   '';
   
-  # On Mac OS X, the java executable shows an -unoffical postfix in the version
+  # On macOS, the java executable shows an -unoffical postfix in the version
   # number. This confuses the build script's version detector.
   # We fix this by creating a wrapper that strips it out of the output.
   
@@ -72,7 +72,7 @@ stdenv.mkDerivation {
     ${if target == "android" then
         ''
           ${stdenv.lib.optionalString (stdenv.system == "x86_64-darwin") ''
-            # Hack to make version detection work with OpenJDK on Mac OS X
+            # Hack to make version detection work with OpenJDK on macOS
             export PATH=${javaVersionFixWrapper}/bin:$PATH
             export JAVA_HOME=${javaVersionFixWrapper}
             javac -version
diff --git a/pkgs/development/ocaml-modules/ocamlnat/default.nix b/pkgs/development/ocaml-modules/ocamlnat/default.nix
index 29ee6535624..9c4c2e21edd 100644
--- a/pkgs/development/ocaml-modules/ocamlnat/default.nix
+++ b/pkgs/development/ocaml-modules/ocamlnat/default.nix
@@ -32,7 +32,7 @@ stdenv.mkDerivation rec {
       but up to 100 times faster. It is based on the optimizing native code
       compiler, the native runtime and an earlier prototype by Alain
       Frisch. It is build upon Just-In-Time techniques and currently
-      supports Unix-like systems (i.e. Linux, BSD or Mac OS X) running on
+      supports Unix-like systems (i.e. Linux, BSD or macOS) running on
       x86 or x86-64 processors. Support for additional architectures and
       operating systems is planned, but not yet available.
     '';
diff --git a/pkgs/development/pharo/vm/build-vm.nix b/pkgs/development/pharo/vm/build-vm.nix
index 1f9e82f866e..c855919f802 100644
--- a/pkgs/development/pharo/vm/build-vm.nix
+++ b/pkgs/development/pharo/vm/build-vm.nix
@@ -90,7 +90,7 @@ stdenv.mkDerivation rec {
     homepage = http://pharo.org;
     license = stdenv.lib.licenses.mit;
     maintainers = [ ];
-    # Pharo VM sources are packaged separately for darwin (OS X)
+    # Pharo VM sources are packaged separately for darwin (macOS)
     platforms = with stdenv.lib;
                   intersectLists
                     platforms.mesaPlatforms
diff --git a/pkgs/development/python-modules/pyqt/4.x.nix b/pkgs/development/python-modules/pyqt/4.x.nix
index a5ae0aaa137..cf1e17d3141 100644
--- a/pkgs/development/python-modules/pyqt/4.x.nix
+++ b/pkgs/development/python-modules/pyqt/4.x.nix
@@ -19,7 +19,7 @@ in buildPythonPackage {
 
     export PYTHONPATH=$PYTHONPATH:$out/lib/${python.libPrefix}/site-packages
     ${stdenv.lib.optionalString stdenv.isDarwin ''
-      export QMAKESPEC="unsupported/macx-clang-libc++" # OS X target after bootstrapping phase \
+      export QMAKESPEC="unsupported/macx-clang-libc++" # macOS target after bootstrapping phase \
     ''}
 
     substituteInPlace configure.py \
diff --git a/pkgs/development/tools/gtk-mac-bundler/default.nix b/pkgs/development/tools/gtk-mac-bundler/default.nix
index 6a16a0372c1..833b41ae985 100644
--- a/pkgs/development/tools/gtk-mac-bundler/default.nix
+++ b/pkgs/development/tools/gtk-mac-bundler/default.nix
@@ -22,7 +22,7 @@ stdenv.mkDerivation rec {
   '';
 
   meta = with lib; {
-    description = "a helper script that creates application bundles form GTK+ executables for Mac OS X";
+    description = "a helper script that creates application bundles form GTK+ executables for macOS";
     maintainers = [ maintainers.matthewbauer ];
     platforms = platforms.darwin;
     homepage = https://wiki.gnome.org/Projects/GTK+/OSX/Bundling;
diff --git a/pkgs/development/libraries/hunspell/default.nix b/pkgs/development/libraries/hunspell/default.nix
index 952050f0e8f..dfb45aa598d 100644
--- a/pkgs/development/libraries/hunspell/default.nix
+++ b/pkgs/development/libraries/hunspell/default.nix
@@ -26,7 +26,7 @@ stdenv.mkDerivation rec {
     longDescription = ''
       Hunspell is the spell checker of LibreOffice, OpenOffice.org, Mozilla
       Firefox 3 & Thunderbird, Google Chrome, and it is also used by
-      proprietary software packages, like Mac OS X, InDesign, memoQ, Opera and
+      proprietary software packages, like macOS, InDesign, memoQ, Opera and
       SDL Trados.
 
       Main features:
@@ -38,7 +38,7 @@ stdenv.mkDerivation rec {
       * C++ library under GPL/LGPL/MPL tri-license.
       * Interfaces and ports:
         * Enchant (Generic spelling library from the Abiword project),
         * XSpell (Mac OS X port, but Hunspell is part of the OS X from version 10.6 (Snow Leopard), and
             now it is enough to place Hunspell dictionary files into
             ~/Library/Spelling or /Library/Spelling for spell checking),
         * Delphi, Java (JNA, JNI), Perl, .NET, Python, Ruby ([1], [2]), UNO.
@@ -38,7 +38,7 @@ stdenv.mkDerivation rec {
       * Interfaces and ports:
         * Enchant (Generic spelling library from the Abiword project),
-        * XSpell (Mac OS X port, but Hunspell is part of the OS X from version 10.6 (Snow Leopard), and
+        * XSpell (macOS port, but Hunspell is part of the macOS from version 10.6 (Snow Leopard), and
             now it is enough to place Hunspell dictionary files into
             ~/Library/Spelling or /Library/Spelling for spell checking),